==> koffice-2.0.0.tar.bz2: koffice-2.0.0/krita/plugins/paintops/deform/deform_paintop_plugin.cpp <==
/*
 * deformpaintop_plugin.cc -- Part of Krita
 *
 * Copyright (c) 2008 Lukáš Tvrdý (lukast.dev@gmail.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "deform_paintop_plugin.h"
#include <klocale.h>
#include <kiconloader.h>
#include <kcomponentdata.h>
#include <kstandarddirs.h>
#include <kis_debug.h>
#include <kgenericfactory.h>

#include <kis_paintop_registry.h>

#include "kis_deform_paintop.h"
#include "kis_deform_paintop_factory.h"
#include "kis_global.h"

typedef KGenericFactory<DeformPaintOpPlugin> DeformPaintOpPluginFactory;
K_EXPORT_COMPONENT_FACTORY(kritadeformpaintop, DeformPaintOpPluginFactory("krita"))


DeformPaintOpPlugin::DeformPaintOpPlugin(QObject *parent, const QStringList &)
        : KParts::Plugin(parent)
{
    setComponentData(DeformPaintOpPluginFactory::componentData());
    KisPaintOpRegistry *r = KisPaintOpRegistry::instance();
    r->add(new KisDeformPaintOpFactory);

}

DeformPaintOpPlugin::~DeformPaintOpPlugin()
{
}

#include "deform_paintop_plugin.moc"

==> koffice_2.2.2.orig.tar.bz2: koffice-2.2.2/krita/plugins/paintops/deform/deform_paintop_plugin.cpp <==
/*
 * Copyright (c) 2008 Lukáš Tvrdý (lukast.dev@gmail.com)
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "deform_paintop_plugin.h"
#include <klocale.h>
#include <kiconloader.h>
#include <kcomponentdata.h>
#include <kstandarddirs.h>
#include <kis_debug.h>
#include <kpluginfactory.h>

#include <kis_paintop_registry.h>

#include "kis_deform_paintop.h"
#include "kis_deform_paintop_factory.h"
#include "kis_global.h"

K_PLUGIN_FACTORY(DeformPaintOpPluginFactory, registerPlugin<DeformPaintOpPlugin>();)
K_EXPORT_PLUGIN(DeformPaintOpPluginFactory("krita"))


DeformPaintOpPlugin::DeformPaintOpPlugin(QObject *parent, const QVariantList &)
        : QObject(parent)
{
    //setComponentData(DeformPaintOpPluginFactory::componentData());
    KisPaintOpRegistry *r = KisPaintOpRegistry::instance();
    r->add(new KisDeformPaintOpFactory);

}

DeformPaintOpPlugin::~DeformPaintOpPlugin()
{
}

#include "deform_paintop_plugin.moc"
